from distutils.core import setup
setup(
  name = "qson",
  packages = ["qson"], # this must be the same as the name above
  version = '0.0.3',
  description = "Quick JSON based key value store over http",
  author = "John Andersen",
  author_email = "johnandersenpdx@gmail.com",
  url = "https://github.com/pdxjohnny/qson", # use the URL to the github repo
  download_url = "https://github.com/pdxjohnny/qson/tarball/0.0.1",
  keywords = ["server", "http", "https", "ssl"], # arbitrary keywords
  classifiers = [],
)
